betty.html module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.html module

Provide the HTML API, for generating HTML pages.

class betty.html.CssProvider

  Bases: `ABC`

  Provide CSS for HTML pages.

  abstract property public_css_paths: list[str]

    The public URL paths to the CSS files to include in each HTML page.

class betty.html.JsProvider

  Bases: `ABC`

  Provide JavaScript for HTML pages.

  abstract property public_js_paths: list[str]

    The public URL paths to the JavaScript files to include in each HTML page.